# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 6.7.2
# WARNING! All changes made in this file will be lost!

from PySide6 import QtCore

qt_resource_data = b"\
\x00\x00#\xcf\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\
\x00\x00\x00\xc5zTXtRaw prof\
ile type exif\x00\x00x\
\xdamP\xdb\x0d\xc3 \x0c\xfc\xf7\x14\x1d\x01?\x02\xf6\
8\xa4I\xa5n\xd0\xf1k\xb0\x13%UO\xe2\xfc8\
\xeb\x00\xc3\xfey\xbf\xe01@( K\xd3j\xb5\x16\
\x87\x98\x18uO\xb4\x04\xfad,2yBR\xf2\xfa\
\xd6\x87S o\xb1G\x8eRk\xce\x1f}<\x0d\x22\
t\xcf\x96\x8b\x91>SX\xef\x82\xe5\x0d\xa4?Fy\
\x11\x8f\x17\x91'[\x1aY\x1a1\x85\x80i\xd0\xe3[\
\xa5\x9a\xb6\xeb\x17\xd6\xbd\xdc\xa1q`\x10\xb7\xe9}\x9a\
\xfc\xd6\xd2|{\xdb\xe2M&\xda\x19\xb983k<\
\x80\xc7\x11\xe0\xee\x899#\x9b\x0f\x22\xb7\x99\x8b3\xcd\
Q\x8c\x85\xfc\xdb\xd3\x01\xf8\x02\xe7}Y+'\xc0\x99\
\xfa\x00\x00\x01\x84iCCPICC pro\
file\x00\x00x\x9c}\x91=H\xc3@\x1c\xc5\
_S\xa5*-\x0a\xed \x22\x92\xa1:\xd9EE\x1c\
K\x15\x8b`\xa1\xb4\x15Zu0\xb9\xf4\x0b\x9a4$\
).\x8e\x82k\xc1\xc1\x8f\xc5\xaa\x83\x8b\xb3\xae\x0e\xae\
\x82 \xf8\x01\xe2\xec\xe0\xa4\xe8\x22%\xfe/)\xb4\x88\
\xf5\xe0\xb8\x1f\xef\xee=\xee\xde\x01B\xa3\xc2T\xb3'\
\x0a\xa8\x9ae\xa4\xe211\x9b[\x15}\xaf\xe8G\x10\
C\x08`Lb\xa6\x9eH/f\xd0u|\xdd\xc3\xc3\
\xd7\xbb\x08\xcf\xea~\xee\xcf\x11P\xf2&\x03<\x22q\
\x94\xe9\x86E\xbcA<\xbbi\xe9\x9c\xf7\x89C\xac$\
)\xc4\xe7\xc4\x93\x06]\x90\xf8\x91\xeb\xb2\xcbo\x9c\x8b\
\x0e\x0b<3ddR\xf3\xc4!b\xb1\xd8\xc1r\x07\
\xb3\x92\xa1\x12\xcf\x10\x87\x15U\xa3|!\xeb\xb2\xc2y\
\x8b\xb3Z\xa9\xb1\xd6=\xf9\x0b\xfdym%\xcdu\x9a\
\xa3\x88c\x09\x09$!BF\x0deT`!B\xab\
F\x8a\x89\x14\xed\xc7\xba\xf8G\x1c\x7f\x92\x5c2\xb9\xca\
`\xe4X@\x15*$\xc7\x0f\xfe\x07\xbf\xbb5\x0b\xd3\
Sn\x92?\x06\xf4\xbe\xd8\xf6\xc78\xe0\xdb\x05\x9au\
\xdb\xfe>\xb6\xed\xe6\x09\xe0}\x06\xae\xb4\xb6\xbf\xda\x00\
\xe6>I\xaf\xb7\xb5\xf0\x110\xb8\x0d\x5c\x5c\xb75y\
\x0f\xb8\xdc\x01\x86\x9ft\xc9\x90\x1c\xc9KS(\x14\x80\
\xf73\xfa\xa6\x1c\x10\xbc\x05\x06\xd6\xdc\xdeZ\xfb8}\
\x002\xd4\xd5\xf2\x0dpp\x08L\x14){\xbd\xcb\xbb\
\xfb:{\xfb\xf7L\xab\xbf\x1f\x97Kr\xb55\xc1\x08\
0\x00\x00\x19kiTXtXML:com\
.adobe.xmp\x00\x00\x00\x00\x00<\
?xpacket begin=\x22\
\xef\xbb\xbf\x22 id=\x22W5M0MpC\
ehiHzreSzNTczkc9\
d\x22?>\x0a<x:xmpmeta \
xmlns:x=\x22adobe:n\
s:meta/\x22 x:xmptk\
=\x22XMP Core 4.4.0\
-Exiv2\x22>\x0a <rdf:R\
DF xmlns:rdf=\x22ht\
tp://www.w3.org/\
1999/02/22-rdf-s\
yntax-ns#\x22>\x0a  <r\
df:Description r\
df:about=\x22\x22\x0a    \
xmlns:xmpMM=\x22htt\
p://ns.adobe.com\
/xap/1.0/mm/\x22\x0a  \
  xmlns:stEvt=\x22h\
ttp://ns.adobe.c\
om/xap/1.0/sType\
/ResourceEvent#\x22\
\x0a    xmlns:stRef\
=\x22http://ns.adob\
e.com/xap/1.0/sT\
ype/ResourceRef#\
\x22\x0a    xmlns:dc=\x22\
http://purl.org/\
dc/elements/1.1/\
\x22\x0a    xmlns:exif\
=\x22http://ns.adob\
e.com/exif/1.0/\x22\
\x0a    xmlns:GIMP=\
\x22http://www.gimp\
.org/xmp/\x22\x0a    x\
mlns:photoshop=\x22\
http://ns.adobe.\
com/photoshop/1.\
0/\x22\x0a    xmlns:ti\
ff=\x22http://ns.ad\
obe.com/tiff/1.0\
/\x22\x0a    xmlns:xmp\
=\x22http://ns.adob\
e.com/xap/1.0/\x22\x0a\
   xmpMM:Documen\
tID=\x22adobe:docid\
:photoshop:89c85\
ad7-1cf9-11ea-99\
59-d7f4e8b866ec\x22\
\x0a   xmpMM:Instan\
ceID=\x22xmp.iid:22\
39ac63-99de-4646\
-a587-eb1d8c25c6\
2b\x22\x0a   xmpMM:Ori\
ginalDocumentID=\
\x22xmp.did:107ce1f\
0-9400-a748-8c5d\
-f3b99246c8a3\x22\x0a \
  dc:format=\x22ima\
ge/png\x22\x0a   exif:\
ApertureValue=\x224\
000000/1000000\x22\x0a\
   exif:Compress\
edBitsPerPixel=\x22\
5/1\x22\x0a   exif:Cus\
tomRendered=\x220\x22\x0a\
   exif:DateTime\
Original=\x222012-0\
3-14T13:05:24\x22\x0a \
  exif:DigitalZo\
omRatio=\x224416/44\
16\x22\x0a   exif:Exif\
Version=\x220221\x22\x0a \
  exif:ExposureB\
iasValue=\x220/3\x22\x0a \
  exif:ExposureM\
ode=\x220\x22\x0a   exif:\
ExposureTime=\x221/\
60\x22\x0a   exif:File\
Source=\x223\x22\x0a   ex\
if:FlashpixVersi\
on=\x220100\x22\x0a   exi\
f:FNumber=\x2240/10\
\x22\x0a   exif:FocalL\
ength=\x2221461/100\
0\x22\x0a   exif:Focal\
PlaneResolutionU\
nit=\x222\x22\x0a   exif:\
FocalPlaneXResol\
ution=\x224416000/2\
92\x22\x0a   exif:Foca\
lPlaneYResolutio\
n=\x223312000/219\x22\x0a\
   exif:MaxApert\
ureValue=\x22128/32\
\x22\x0a   exif:Meteri\
ngMode=\x225\x22\x0a   ex\
if:PixelXDimensi\
on=\x22250\x22\x0a   exif\
:PixelYDimension\
=\x22250\x22\x0a   exif:S\
ceneCaptureType=\
\x220\x22\x0a   exif:Sens\
ingMethod=\x222\x22\x0a  \
 exif:ShutterSpe\
edValue=\x22189/32\x22\
\x0a   exif:WhiteBa\
lance=\x220\x22\x0a   GIM\
P:API=\x222.0\x22\x0a   G\
IMP:Platform=\x22Wi\
ndows\x22\x0a   GIMP:T\
imeStamp=\x22172676\
2470562195\x22\x0a   G\
IMP:Version=\x222.1\
0.38\x22\x0a   photosh\
op:ColorMode=\x223\x22\
\x0a   photoshop:Da\
teCreated=\x222012-\
03-14T13:05:24\x22\x0a\
   photoshop:ICC\
Profile=\x22sRGB IE\
C61966-2.1\x22\x0a   t\
iff:Make=\x22Canon\x22\
\x0a   tiff:Model=\x22\
Canon PowerShot \
G10\x22\x0a   tiff:Ori\
entation=\x221\x22\x0a   \
tiff:ResolutionU\
nit=\x222\x22\x0a   tiff:\
XResolution=\x22720\
000/10000\x22\x0a   ti\
ff:YCbCrPosition\
ing=\x222\x22\x0a   tiff:\
YResolution=\x22720\
000/10000\x22\x0a   xm\
p:CreateDate=\x2220\
12-03-14T13:05:2\
4\x22\x0a   xmp:Creato\
rTool=\x22GIMP 2.10\
\x22\x0a   xmp:Metadat\
aDate=\x222024:09:1\
9T17:14:28+01:00\
\x22\x0a   xmp:ModifyD\
ate=\x222024:09:19T\
17:14:28+01:00\x22>\
\x0a   <xmpMM:Histo\
ry>\x0a    <rdf:Seq\
>\x0a     <rdf:li\x0a \
     stEvt:actio\
n=\x22created\x22\x0a    \
  stEvt:instance\
ID=\x22xmp.iid:107c\
e1f0-9400-a748-8\
c5d-f3b99246c8a3\
\x22\x0a      stEvt:so\
ftwareAgent=\x22Ado\
be Photoshop CC \
2015 (Windows)\x22\x0a\
      stEvt:when\
=\x222012-03-14T13:\
05:24\x22/>\x0a     <r\
df:li\x0a      stEv\
t:action=\x22conver\
ted\x22\x0a      stEvt\
:parameters=\x22fro\
m image/jpeg to \
application/vnd.\
adobe.photoshop\x22\
/>\x0a     <rdf:li\x0a\
      stEvt:acti\
on=\x22saved\x22\x0a     \
 stEvt:changed=\x22\
/\x22\x0a      stEvt:i\
nstanceID=\x22xmp.i\
id:50c42a08-8daa\
-fb4a-af9c-b6348\
bb6a55f\x22\x0a      s\
tEvt:softwareAge\
nt=\x22Adobe Photos\
hop CC 2015 (Win\
dows)\x22\x0a      stE\
vt:when=\x222019-12\
-12T16:07:29Z\x22/>\
\x0a     <rdf:li\x0a  \
    stEvt:action\
=\x22saved\x22\x0a      s\
tEvt:changed=\x22/\x22\
\x0a      stEvt:ins\
tanceID=\x22xmp.iid\
:431c15ae-504c-4\
44a-85f0-08b4ffb\
9fb9b\x22\x0a      stE\
vt:softwareAgent\
=\x22Adobe Photosho\
p CC 2015 (Windo\
ws)\x22\x0a      stEvt\
:when=\x222019-12-1\
2T16:08:06Z\x22/>\x0a \
    <rdf:li\x0a    \
  stEvt:action=\x22\
converted\x22\x0a     \
 stEvt:parameter\
s=\x22from applicat\
ion/vnd.adobe.ph\
otoshop to image\
/png\x22/>\x0a     <rd\
f:li\x0a      stEvt\
:action=\x22derived\
\x22\x0a      stEvt:pa\
rameters=\x22conver\
ted from applica\
tion/vnd.adobe.p\
hotoshop to imag\
e/png\x22/>\x0a     <r\
df:li\x0a      stEv\
t:action=\x22saved\x22\
\x0a      stEvt:cha\
nged=\x22/\x22\x0a      s\
tEvt:instanceID=\
\x22xmp.iid:a1fb072\
1-5ece-3747-b056\
-3fe3f5c5e8c9\x22\x0a \
     stEvt:softw\
areAgent=\x22Adobe \
Photoshop CC 201\
5 (Windows)\x22\x0a   \
   stEvt:when=\x222\
019-12-12T16:08:\
06Z\x22/>\x0a     <rdf\
:li\x0a      stEvt:\
action=\x22saved\x22\x0a \
     stEvt:chang\
ed=\x22/\x22\x0a      stE\
vt:instanceID=\x22x\
mp.iid:75ca8a53-\
f03f-4709-b94d-0\
b607a4ee0ee\x22\x0a   \
   stEvt:softwar\
eAgent=\x22Gimp 2.1\
0 (Windows)\x22\x0a   \
   stEvt:when=\x222\
024-09-19T17:14:\
30\x22/>\x0a    </rdf:\
Seq>\x0a   </xmpMM:\
History>\x0a   <xmp\
MM:DerivedFrom\x0a \
   stRef:documen\
tID=\x22xmp.did:107\
ce1f0-9400-a748-\
8c5d-f3b99246c8a\
3\x22\x0a    stRef:ins\
tanceID=\x22xmp.iid\
:431c15ae-504c-4\
44a-85f0-08b4ffb\
9fb9b\x22\x0a    stRef\
:originalDocumen\
tID=\x22xmp.did:107\
ce1f0-9400-a748-\
8c5d-f3b99246c8a\
3\x22/>\x0a   <exif:Fl\
ash\x0a    exif:Fir\
ed=\x22True\x22\x0a    ex\
if:Function=\x22Fal\
se\x22\x0a    exif:Mod\
e=\x223\x22\x0a    exif:R\
edEyeMode=\x22True\x22\
\x0a    exif:Return\
=\x220\x22/>\x0a   <exif:\
ISOSpeedRatings>\
\x0a    <rdf:Seq>\x0a \
    <rdf:li>200<\
/rdf:li>\x0a    </r\
df:Seq>\x0a   </exi\
f:ISOSpeedRating\
s>\x0a  </rdf:Descr\
iption>\x0a </rdf:R\
DF>\x0a</x:xmpmeta>\
\x0a               \
                \
                \
                \
                \
                \
     \x0a          \
                \
                \
                \
                \
                \
          \x0a     \
                \
                \
                \
                \
                \
               \x0a\
                \
                \
                \
                \
                \
                \
    \x0a           \
                \
                \
                \
                \
                \
         \x0a      \
                \
                \
                \
                \
                \
              \x0a \
                \
                \
                \
                \
                \
                \
   \x0a            \
                \
                \
                \
                \
                \
        \x0a       \
                \
                \
                \
                \
                \
             \x0a  \
                \
                \
                \
                \
                \
                \
  \x0a             \
                \
                \
                \
                \
                \
       \x0a        \
                \
                \
                \
                \
                \
            \x0a   \
                \
                \
                \
                \
                \
                \
 \x0a              \
                \
                \
                \
                \
                \
      \x0a         \
                \
                \
                \
                \
                \
           \x0a    \
                \
                \
                \
                \
                \
                \
\x0a               \
                \
                \
                \
                \
                \
     \x0a          \
                \
                \
                \
                \
                \
          \x0a     \
                \
                \
                \
                \
                \
               \x0a\
                \
                \
                \
                \
                \
                \
    \x0a           \
                \
\x0a<?xpacket end=\x22\
w\x22?>_\x5c,\x10\x00\x00\x00\x06bKGD\
\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pH\
Ys\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\
\x00\x00\x07tIME\x07\xe8\x09\x13\x10\x0e\x1e\x01\xd5\
\x1a\xd2\x00\x00\x07\x84IDATx\xda\xd5\x9bil\
\x9c\xc5\x19\xc7\x7f\xf3\x1e\xbb\x8ew\xbd\xeb\xec\xae\xd9]\
\x13\xaf\x89\xe3\xd8\x0enl\x83\x14\x12'\x86\x90\x0f\xb4\
\xa9T\x95D\xa2\x5c\x91\xa0\xa5\x82R.\x85\xd0\xa2V\
\xa8\xa2\x90\xaa8U\x12!Q@\x08DE?T-\
\x08\x81DC[Q\x08jA\x84\x0f\xa0\x80J9\x1d\
W8U\x12\x0e'&f\xe3\xc4\xc7\xf2\xc1\xb3\xe8e\
\xb3\xc7\xcc\xec\xe5<\xd2Hk\xbf\xef\xcc3\xff9\x9e\
\xfb\x15T\x9f\xda\x80\xd5@\x1f\xd0\x05,\x05\x92@\x18\
X$\xdf\x99\x02\x8e\x01\x87\x81Q\xe0\x03\xe0m\xe0u\
\xe0c\xce0\xb2\x80A`\x18x\x07\x98\x012\x86m\
\x06\xf8/\xb0\x03X\x0b\xd8\x0b\x19x\x04\xd8\x0a\xbc\x07\
\xcc\x95\x01\xbaP\x9b\x03\xde\x07\xb6\x01\xd1\x85\x04|1\
\xf0k`\xbc\x0a\xa0\x0b\xb5\xa3\xc0v\xb9\xe8u#\x07\
\xb8\x018RC\xe0\xb9\xed\x13\xe0\xa7\x80[k\xf0]\
\xc0\xbf\xea\x08<\xb7\xbd\x02\xf4\xd4\x02\xb8\x00\xb6\x00\x13\
\x0b\x08|\xb6}\x01\x5c#\xe7X\x15\xb2\x81]U\x12\
p\x95\x14\x94\xf7\xcb\xeby\x1a\xb5\xb7\xb7GB\xa1\xf0\
\xdd\x8e\xe3\x5c\xa1\x0b\xbe\x01xj\x01\x03\xcfm\xcfx\
l\x0c\x96,Y\x92\x08\x06\x83\xc3\x8e\xe3d\x05\xf5\x83\
\xba\xe0\x9f?\x83\xc0g\xdb?\x92\xc9\xe4\xf2@ \xf0\
\x80\xe38\xc7s\x9e\xbd\xea\xbd\xd3\xa5\x8e\xfd\x9f\x81\xcb\
*p\x85\x8e\x02\xfb\xa4\x85w\x00\xf8\x148!\x9f-\
\x02Z\x80\x0ei1\xae\x91\xea\xd5LP\x89\xafae\
2\x99L>\x8c\x13\x92\xdft)\x81\xb7\xb3\xcc]\xf8\
L\x1e\xb7\x0d\x80_\x03\x83_\xf6yP\x8e\xa1\xc4O\
\x08\x91\x11B\xa8Z\x98]\xa5&\xb1\xa5\x0c\x81w\x10\
\xb8\x1dh\xaa\xc0\xc9i\x92c\x1d,\x0a\xdc\xb2t\xe7\
\xb8\xb9\x18\xd3\xe5\x86\xaa\xee\xa4<5\xa1*h\xa1\x90\
\x1c\xfb\xa4\xc1\x8e\xe7k\xbf*f\xe1\xfd\xdb`\xc0\x03\
\xd2\x09\xaa\xae\xf9\xe98\xebl\xdb\xfe\xa4\x0c\xe0\xd9\xf6\
d!\x1e7\x18\x0c\xf6\xb2\x14*U\xa3\x1bo\xbcI\
\xa4\xda\xda\xd7\xfb\xfd\xfe\x97\x85\x103\x15\xd0\x12\x1f\x16\
rltm\xfb=@\xa0\xda;\xdf\xb9\xacs\xb5e\
Y3\x15T\x93\xd3\xf94\xcd=\x06;_u\xf0}\
+W:M\xc1\xe0\xbeJ[\x8dB\x88\xa1\x5c\x7f~\
\x5c\xf3\xce\xc7\xca\x08\x9a\x84\x0b\x99\xac\xb9tV\xcbY\
wT\x12\xbcm\xdb\xc7\xc2\xe1\xd0\xdd\xf1x<\xec\xe5\
\xb3US\xda\x9b\x0a\xbc\x15\xc0\xdf\xe5\x11< \xaf\xd0\
N\xe0:`\xe5ing\xe7\xf2n\xc7q&+\x01\
<\xab5\x5c\xd7\xfde\xbe\x1dyOc\xb0\x9d\x06\xc0\
\x03\xc0o\x80t\x91q\x8fyUh\xdf\xb7V\xda\xc1\
@`o\xa5\x80{4\xc7G\xb9\xe1\xb5A\x0d\xa3\xe7\
\xff\x06\x06\xce\xa5\x92\xa9\xca\xf8[\xb2\x9d\xceN\xb6\xde\
V.x\xcb\xb2\xf2\xd9\x0as\xc0\x85\xde\x09\xee\xd0\x18\
t\x9bf\xb8\xec\x19M\x8b\xf2o\x00\xa9T\xfb%\x8e\
m~\xf4\x15\x8c\xa4]\xde\x89\xbe\xa3a\xdb\x075\x16\
\xc0\x95am\x9d\xc9\xa7S\xa9s\xce\xf3\xfb\xfd\x07\x0d\
@\xcf\xda\xb6}R\xd1H\xfa\xc0\x1b\xb7W\xd5\xaf\x0f\
\x19\xdc\xfd\xed\x06\xc7\xf6\x94n\x9f\x86\x86\x86\xbd\xd1h\
t\x9d\x10\xe2a\xc5>\xb32G\xc1e\x1a\x8c6\x18\
,@\x8f\x94\xf8Z\x80|>\xf7\x0bE\xe0\xafG#\
\x91o\xf7\xf7\xf7[\x92\xdf\x06\x0d>W\x02\xdc\xab\x11\
\x8a\xf6\x19\xaa\xbeWu\xad\xb4X,\xdawvkk\
_8\x1c\xfaI \x10\xf8\xa3\xcf\xe7\xbek\xdb\xf6\xd7\
\x1a\xc4\xef\xf7\xff'\x12\x89l\xee\xed\xed\xcdM\x96\xf8\
\xe4\x5cU\xf8\xdc\x87\x0cx\xa8\xbc\xfc\xbcq\xaa\xc8\xb2\
\xae5\x10d?\xf7\x8eq\xf5\xd5W\x8aT\xaa-\xb6\
\xb4\xbd}m\x22\x1e\xbfdp\xcd\x9ab\xa1p\xd5\x08\
\xd6\xd3\xc8\xfc\x9b\xca\xcb\xc3\xba\xc0/\xfd\xfe&k\xd5\
\xaa\x0b\xa2\xb1H\xf4Y\x83\x05x\xbb\x0c\xebyX\x91\
\xc7\x9b\x8eLT\xaa\xd0H\xa9\x17\xd6_t\xb1\x95N\
\xa7\x93\x87\x8f\x1c\xba\xf8\xcb/\xd3\x1b^|\xe9\x9f\xab\
\xa6\xa6\xa6\xbagff\xfcB\x88\xd9L&\xa3\x93\xdb\
;W\x86\xc7L\x16bD\xf1\xbd$\x1a\x81\x8f\x82\x11\
\x94\xee\xee\x9e\xa5\x91H\xf4\x91PS\xe8-!\xc4l\
n_\xc7q\xa6\x92\x89\xc4\x0f\x0dN\xc1v\xc3\x13\xb0\
Yq\xfcI\x00U\x95\xb31\x1f\xa7T*\x15s]\
\xb7\xa8\x19\xdd\xd8\xd8\xf8F\xaa\xad\xcd\x95\xbaWg\x01\
F\xa4\x99\xaeK\x1b\x15\xc7?e\x95q\xcf\xe8\xed\xed\
m\x18\x1f\x1f\x7fzzz\xba\xbb\xd8{\x8d\x8d\x8d/\
|<66\x0d\xfcI\x93\xc5\xd2jG\x99,\xe6\x8b\
\x13Th\x91\xf7\x8f\xa1\xb5\xeb\xac\xd1\xd1\xd1\x87''\
'/*\x19\xcc\x0b\x85\xf6\xc8\x9fO\x94\x0aE\xe7\x89\
L_n\x80k\x91\xe2{\xa7\x00\xc6\x14\x8f\xcb\xf5\xde\
\x9e\xcd\xcd\xcdw)\x1a*\xe3\x03\x03\x03\x8d\x9e\xae/\
j^\x83C29\xa3C\xd7\xab\x8emI\x06*\xb4\
,\xfb\xa35\x91\xb8bbb\xe2\x1e\xa5\xb4RC\xc3\
k\xfb\xf7\xefO{\xfe\xf5\x07M0YwX\x87\x96\
)\xbew\x18\xe0/:\x86P,\x1a]mYVZ\
u\x07\x13\x89\xc4\xd6\x1c\xa6A\xc5d\xc7\x9c\xf4RM\
\xcab\xb4\x0c!Ug\xe5hgGG\x97\xcfu\x0f\
\xe9\x1c\xe1\xfe\xbe\xbe|\x02\xf2\xd1R\xd2\x19\xb8\xc50\
\xd5\xadc\x0a\x0f\x03\xfc@\xd5\xbfv\x1cgL\x07|\
0\x18\xfchhh(_\xdco\xb0\x84n\xdeT\x86\
`\xd7q\x86\xae\x02H\xa9\xb8\xc3&\x89\x88\xc8\xe2\xc5\
\x8f\x17\x91\xee\xe7\xcb\xe8\xcf}\xc0_e\xdc`L&\
F\xcb\xa1\x874\xdc\xe1\x8el\xa7wK\x85\x95t\xc1\
\xbb\xae\xfby*\x95Z\xa19\xf9\x862\xc1\xab\xca\x97\
\xd3\x12#\xbf\xab$x!\xc4t<\x9e\xdcH\xedi\
\x9b\xc6<w{;\xae\xcb\x17\xb73\xcd\xbfEc-\
w\xd4\x01|\x93\x0c\xd8\xaa\x96\xd2\xac\xcf\xb5\x08\xdf\xc7\
,\xd7\xfeM\xc1\xd7\x14z\xa2\xa3\xa3S\xd4a\x01t\
j\x19F\xf2\xa9\xd7\xdb\xcb\x05\xef\xf3\xf9_\x1b\x188\
\xbf\xb1\x0e\xe0\x07\xf1\xa4\xcd\x15\xda\x9d\xf9\x06\x89\xca\xc4\
\x84\x11x\xc7q\x0e.\xef\xean\xab\x03\xf8\x98\xcc0\
\xe9\x94\xd3\x15\xccd\xdfkPi\x91\xb1,\xebD[\
[\xea\xc2:\x80\x0f\xc8\x04\xad\xce|w\x14\x1c-\x12\
\x89\xfe\xc2D\xe8\x85\xc3\xcd\xb7\xd4\x09\xfc\x1e\xcd\xb9~\
^p\xf7[\x93\xad\x9b\x84\x10\xda\xe1kyb\xf6R\
\xe5\x02\x89\x1cj1\xd8\xf9\x0cpk\xfeK\xd4\xd2r\
\x9em\xdb\xc7M\xd2O\xd4\xb8DF\xf28`\x00~\
\x1f\x85\x8a\xaa]\xd7w\x7f\x85ro5-\x92\xd2h\
\x932\xc8Z\x90\xa2\x1a\x81\x11\x15#\xa9\xa6er\x0a\
\xed:\x15F\xdf\x93\x0e\x82R\xca\x19\xf5dj\xcd\x0a\
%\x0b\xb4\xdf\x17s\xabs\x1f<\x0e\xfc\xa8D\x96\x87\
\xb9\xb99\x93\x9d\xacY\xa9\xac\x87\xf6H\xd7zF\xb5\
\xc3b\x8a\xa4\xb3+P\x9bW\xcb\xf6\x02`d\x95~\
7_|@\x08q\xe2\x0cZ\x80\xe7L\xc1g\xe91\
\xbeYU\x95\x8e\xc7\x93k\x98\xff\x18a\xa1\x83\x7f\x80\
\x0a|C\xd4\x0c\xfc/\xeb:Fc-\xd7xd\xc6\
\xb5\xc0\xf1\x05\x08|RJ\xfb\x8ay\xa2\xdf\x01f#\
\x91\xd8\xee<\xcfz\xd0\xcf\xf9W\xb3\xed+\xa5\xe7M\
H\x84\xc3\xcd?\xeeYqn\xa1\xe3\xe4\x027Ki\
^/\xe0\x9f\x01\xb7Q\x87\xcf\xe6r\xdd\xd1\xdff]\
\xe9\x1a\xb5\x09\xe9\xd5\xb5\xb0\x80(\x06\xfcL\x06\x1b\xab\
\xf5\xe9\xec\x88\x0cf,(\xe0\xb9d3_\x84\xb8K\
\x86\xd9f\xcb\x00=+\x17t\xb7\x8c\xe19\x15\xbf\xe7\
U^\x0c\x01\x9c\xc3\xfc\xe7\xf3\xfd\xcc\x7f\x89\xd2\x01$\
\xa4s\x93-\xba:%#5G\xa4\x95\xf8!\xf0\x16\
\xf3\xe5;\xa3\x06\xb9Ae\xfa\x0a\xc4\xc3s\xf1\xb3\x0a\
\xea\x18\x00\x00\x00\x00IEND\xaeB`\x82\
"

qt_resource_name = b"\
\x00\x05\
\x00o\xa6S\
\x00i\
\x00c\x00o\x00n\x00s\
\x00\x11\
\x0f)y\xe7\
\x00d\
\x00e\x00l\x00t\x00o\x00d\x00o\x00n\x00-\x00l\x00o\x00g\x00o\x00.\x00p\x00n\x00g\
\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x92\x14\xa9,\xb7\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x03, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
